vim.opt.termguicolors = true

vim.ayucolor="dark"

vim.g.indentLine_char = ""
vim.g.indentLine_first_char = ""
vim.g.indentLine_showFirstIndentLevel = 1
vim.g.indentLine_setColors = 0

vim.opt.cursorline = true
vim.opt.background = 'dark'
-- vim.g.cyberpunk_cursorline='black'

-- vim.cmd('colorscheme ayu')
-- vim.cmd('colorscheme night_owl_light')
-- vim.cmd('colorscheme eva01')
-- vim.cmd('colorscheme cyberpunk')
-- vim.cmd('colorscheme catppuccin-latte')
vim.cmd('colorscheme oxocarbon')

-- examples for your init.lua

-- disable netrw at the very start of your init.lua (strongly advised)
vim.g.loaded_netrw = 1
vim.g.loaded_netrwPlugin = 1

-- setup with some options
require("nvim-tree").setup{ -- BEGIN_DEFAULT_OPTS
auto_reload_on_write = true,
create_in_closed_folder = false,
disable_netrw = false,
hijack_cursor = false,
hijack_netrw = true,
hijack_unnamed_buffer_when_opening = false,
ignore_buffer_on_setup = false,
open_on_setup = false,
open_on_setup_file = false,
open_on_tab = false,
ignore_buf_on_tab_change = {},
sort_by = "name",
root_dirs = {},
prefer_startup_root = false,
sync_root_with_cwd = false,
reload_on_bufenter = false,
respect_buf_cwd = false,
on_attach = "disable",
remove_keymaps = false,
select_prompts = false,
view = {
    adaptive_size = false,
    centralize_selection = false,
    width = 30,
    hide_root_folder = false,
    side = "left",
    preserve_window_proportions = false,
    number = false,
    relativenumber = false,
    signcolumn = "yes",
    mappings = {
        custom_only = false,
        list = {
            -- user mappings go here
        },
    },
    float = {
        enable = false,
        quit_on_focus_loss = true,
        open_win_config = {
            relative = "editor",
            border = "rounded",
            width = 30,
            height = 30,
            row = 1,
            col = 1,
        },
    },
},
renderer = {
    add_trailing = false,
    group_empty = false,
    highlight_git = false,
    full_name = false,
    highlight_opened_files = "none",
    root_folder_modifier = ":~",
    indent_width = 2,
    indent_markers = {
        enable = false,
        inline_arrows = true,
        icons = {
            corner = "└",
            edge = "│",
            item = "│",
            bottom = "─",
            none = " ",
        },
    },
    icons = {
        webdev_colors = true,
        git_placement = "before",
        padding = " ",
        symlink_arrow = " ➛ ",
        show = {
            file = true,
            folder = true,
            folder_arrow = true,
            git = true,
        },
        glyphs = {
            default = "",
            symlink = "",
            bookmark = "",
            folder = {
                arrow_closed = "",
                arrow_open = "",
                default = "",
                open = "",
                empty = "",
                empty_open = "",
                symlink = "",
                symlink_open = "",
            },
            git = {
                unstaged = "🙄",
                staged = "🥺",
                unmerged = "🫢",
                renamed = "📛",
                untracked = "💫",
                deleted = "🗑️",
                ignored = "🤷",
            },
        },
    },
    special_files = { "Cargo.toml", "Makefile", "README.md", "readme.md" },
    symlink_destination = true,
},
hijack_directories = {
    enable = true,
    auto_open = true,
},
update_focused_file = {
    enable = false,
    update_root = false,
    ignore_list = {},
},
ignore_ft_on_setup = {},
system_open = {
    cmd = "",
    args = {},
},
diagnostics = {
    enable = true,
    show_on_dirs = false,
    debounce_delay = 50,
    icons = { error = "☣️ ", warning = "😞", hint = "❤️ ", info = "ℹ️ " }
,
},
filters = {
    dotfiles = false,
    custom = {},
    exclude = {},
},
filesystem_watchers = {
    enable = true,
    debounce_delay = 50,
},
git = {
    enable = true,
    ignore = true,
    show_on_dirs = true,
    timeout = 400,
},
actions = {
    use_system_clipboard = true,
    change_dir = {
        enable = true,
        global = false,
        restrict_above_cwd = false,
    },
    expand_all = {
        max_folder_discovery = 300,
        exclude = {},
    },
    file_popup = {
        open_win_config = {
            col = 1,
            row = 1,
            relative = "cursor",
            border = "shadow",
            style = "minimal",
        },
    },
    open_file = {
        quit_on_open = false,
        resize_window = true,
        window_picker = {
            enable = true,
            chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890",
            exclude = {
                filetype = { "notify", "packer", "qf", "diff", "fugitive", "fugitiveblame" },
                buftype = { "nofile", "terminal", "help" },
            },
        },
    },
    remove_file = {
        close_window = true,
    },
},
trash = {
    cmd = "gio trash",
    require_confirm = true,
},
live_filter = {
    prefix = "[FILTER]: ",
    always_show_folders = true,
},
log = {
    enable = false,
    truncate = false,
    types = {
        all = false,
        config = false,
        copy_paste = false,
        dev = false,
        diagnostics = false,
        git = false,
        profile = false,
        watcher = false,
    },
},
notify = {
    threshold = vim.log.levels.INFO,
},
    }



local hls = {
  PmenuSel = { bg = "#282C34", fg = "NONE" },
  Pmenu = { fg = "#C5CDD9", bg = "#22252A" },

  CmpItemAbbrDeprecated = { fg = "#7E8294", bg = "NONE", strikethrough = true },
  CmpItemAbbrMatch = { fg = "#82AAFF", bg = "NONE", bold = true },
  CmpItemAbbrMatchFuzzy = { fg = "#82AAFF", bg = "NONE", bold = true },
  CmpItemMenu = { fg = "#C792EA", bg = "NONE", italic = true },

  CmpItemKindField = { fg = "#EED8DA", bg = "#B5585F" },
  CmpItemKindProperty = { fg = "#EED8DA", bg = "#B5585F" },
  CmpItemKindEvent = { fg = "#EED8DA", bg = "#B5585F" },

  CmpItemKindText = { fg = "#C3E88D", bg = "#9FBD73" },
  CmpItemKindEnum = { fg = "#C3E88D", bg = "#9FBD73" },
  CmpItemKindKeyword = { fg = "#C3E88D", bg = "#9FBD73" },

  CmpItemKindConstant = { fg = "#FFE082", bg = "#D4BB6C" },
  CmpItemKindConstructor = { fg = "#FFE082", bg = "#D4BB6C" },
  CmpItemKindReference = { fg = "#FFE082", bg = "#D4BB6C" },

  CmpItemKindFunction = { fg = "#EADFF0", bg = "#A377BF" },
  CmpItemKindStruct = { fg = "#EADFF0", bg = "#A377BF" },
  CmpItemKindClass = { fg = "#EADFF0", bg = "#A377BF" },
  CmpItemKindModule = { fg = "#EADFF0", bg = "#A377BF" },
  CmpItemKindOperator = { fg = "#EADFF0", bg = "#A377BF" },

  CmpItemKindVariable = { fg = "#C5CDD9", bg = "#7E8294" },
  CmpItemKindFile = { fg = "#C5CDD9", bg = "#7E8294" },

  CmpItemKindUnit = { fg = "#F5EBD9", bg = "#D4A959" },
  CmpItemKindSnippet = { fg = "#F5EBD9", bg = "#D4A959" },
  CmpItemKindFolder = { fg = "#F5EBD9", bg = "#D4A959" },

  CmpItemKindMethod = { fg = "#DDE5F5", bg = "#6C8ED4" },
  CmpItemKindValue = { fg = "#DDE5F5", bg = "#6C8ED4" },
  CmpItemKindEnumMember = { fg = "#DDE5F5", bg = "#6C8ED4" },

  CmpItemKindInterface = { fg = "#D8EEEB", bg = "#58B5A8" },
  CmpItemKindColor = { fg = "#D8EEEB", bg = "#58B5A8" },
  CmpItemKindTypeParameter = { fg = "#D8EEEB", bg = "#58B5A8" },
}

for key, value in pairs(hls) do
    vim.api.nvim_set_hl(0, key, value)
end


